==> haskell-semigroups-0.19.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 semigroups
version:              0.19.1
visibility:           public
id:                   semigroups-0.19.1-LKdktuRRdRZ1yx9gBXzSbK
key:                  semigroups-0.19.1-LKdktuRRdRZ1yx9gBXzSbK
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/semigroups/
synopsis:             Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.

category:             Algebra, Data, Data Structures, Math
abi:                  5871d871700834e24be2386ff2860940
exposed:              True
exposed-modules:      Data.Semigroup.Generic
import-dirs:          /usr/lib/ghc-8.8.3/site-local/semigroups-0.19.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/semigroups-0.19.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/semigroups-0.19.1
hs-libraries:         HSsemigroups-0.19.1-LKdktuRRdRZ1yx9gBXzSbK
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html:         /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semigroups-0.19.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 semigroups
version:              0.19.1
visibility:           public
id:                   semigroups-0.19.1-FzieqrLdZI71C64LnuY3Qi
key:                  semigroups-0.19.1-FzieqrLdZI71C64LnuY3Qi
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/semigroups/
synopsis:             Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.

category:             Algebra, Data, Data Structures, Math
abi:                  b5851bff51f42f68ac885bd989dc1301
exposed:              True
exposed-modules:      Data.Semigroup.Generic
import-dirs:          /usr/lib/ghc-8.10.2/site-local/semigroups-0.19.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/semigroups-0.19.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/semigroups-0.19.1
hs-libraries:         HSsemigroups-0.19.1-FzieqrLdZI71C64LnuY3Qi
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html:         /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
